# Maya Stubs
Stubs for Autodesk Maya

The goal of this is to get as fully typed stubs for all maya APIs.
This is not a small feat so the stubs will improve over time.

# Status:
- 🚧 maya.cmds: Incomplete
    - [x] Stubs for all commands.
    - [x] Accurate Arguments signatures for most commands (parsed from `cmds.help("command")`).
    - [ ] Accurate Arguments signatures all commands.
    - [ ] Implicit first argument of some commands.
    - [ ] Return Types.
    - [ ] Docstrings.
- 🚫 OpenMaya 1.0: Missing
- 🚫 OpenMaya 2.0: Missing